#
# spec file for package litecoin
#
# Copyright (c) 2013 Peter Conrad
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

# It fails on CentOS 7, dunno why
%if 0%{?rhel} && 0%{?rhel} <= 7
%bcond_with miniupnpc
%else
%bcond_without miniupnpc
%endif

Name:           litecoin
#Version:        0.10.2.2
Version:        0.15.1
Release:        1%{?dist}
License:        MIT
Summary:        P2P digital currency
Url:            http://litecoin.org/
%if 0%{?suse_version} > 0
Group:          Productivity/Networking/Other
%endif

Source0:        https://github.com/%{name}-project/%{name}/archive/v%{version}/%{name}-%{version}.tar.gz
Source1:        %{name}.desktop
Source2:        %{name}d-safe
Source3:        %{name}d.apparmor

%if 0%{?suse_version} > 0
BuildRequires:  libqt4-devel boost-devel libminiupnpc-devel libcurl-devel libjansson-devel libdb-4_8-devel
BuildRequires:  apparmor-parser
BuildRequires:  update-desktop-files
%else
BuildRequires:  boost-devel
BuildRequires:  jansson-devel
BuildRequires:  libcurl-devel
BuildRequires:  libdb4-cxx-devel >= 4.8
BuildRequires:  libevent-devel
BuildRequires:  openssl-devel
BuildRequires:  qrencode-devel
BuildRequires:  qt4-devel
%endif
%{?with miniupnpc:BuildRequires:  miniupnpc-devel}
BuildRequires:  automake autoconf libtool
BuildRequires:  protobuf-devel
%if 0%{?suse_version} > 0
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%endif

%description
Litecoin is a peer-to-peer Internet currency that enables instant payments to
anyone in the world. It differs from its parent Bitcoin in that can be
efficiently mined with consumer-grade hardware. Litecoin provides faster
confirmations (targeted at every 2.5 minutes on average) and uses memory-hard,
scrypt-based mining to target the CPUs and GPUs most people already have. The
Litecoin network is scheduled to produce four times as many currency units as
Bitcoin.

One of the aims of Litecoin was to provide a mining algorithm that could run at
the same time, on the same hardware used to mine bitcoins. With the rise of
specialized ASICs for Bitcoin, Litecoin continues to satisfy these goals. It
is unlikely for FPGA or ASIC mining to take over Litecoin until the currency is
widely used.

%package devel
Summary: Development files for %{name}
Group: Development/Libraries
Requires: %{name} = %{version}-%{release}

%description devel
LiteCoin development package

%package cli
Summary: LiteCoin CLI
Requires: %{name} = %{version}-%{release}

%description cli
LiteCoin CLI package

%package daemon
Summary: LiteCoin daemon
Requires: %{name} = %{version}-%{release}

%description daemon
LiteCoin daemon package

%package qt
Summary: LiteCoin GUI
Requires: %{name} = %{version}-%{release}

%description qt
LiteCoin GUI package

%prep
%setup -q

%build
./autogen.sh 0%{?_without_miniupnpc}
%configure
%__make %{?_smp_mflags}

%install
%make_install
%__install -D -m 644 %{SOURCE1} %{buildroot}%{_datadir}/applications/$(basename %{SOURCE1})

%files
%defattr(-,root,root,-)
%doc COPYING README.md
%{_libdir}/libbitcoinconsensus.so.0
%{_libdir}/libbitcoinconsensus.so.0.0.0

%files devel
%defattr(-,root,root,-)
%{_includedir}/bitcoinconsensus.h
%{_libdir}/libbitcoinconsensus.a
%{_libdir}/libbitcoinconsensus.la
%{_libdir}/libbitcoinconsensus.so
%{_libdir}/pkgconfig/libbitcoinconsensus.pc

%files cli
%defattr(-,root,root,-)
%{_bindir}/%{name}-cli
%{_bindir}/%{name}-tx
%{_mandir}/man1/%{name}-cli.1.gz
%{_mandir}/man1/%{name}-tx.1.gz
%{_bindir}/test_%{name}

%files daemon
%defattr(-,root,root,-)
%{_bindir}/bench_%{name}
%{_bindir}/%{name}d
%{_mandir}/man1/%{name}d.1.gz
%if 0%{?suse_version} > 0
%config %{_sysconfdir}/apparmor.d/usr.bin.%{name}d-safe
%endif

%files qt
%defattr(-,root,root,-)
%{_bindir}/%{name}-qt
%{_mandir}/man1/%{name}-qt.1.gz
%{_bindir}/test_%{name}-qt
%{_datadir}/applications/%{name}.desktop

%changelog
* Fri Sep 07 2018 Vadim Raskhozhev <iamdexpl@gmail.com> - 0.15.1-1
- miniupnpc condition converted into bcond
- New version

* Sat Nov 18 2017 Vadim Raskhozhev <iamdexpl@gmail.com> - 0.14.2-1
- New version

* Mon Nov 09 2015 Vadim Raskhozhev <iamdexpl@gmail.com> - 0.10.2.2-2
- Built for Fedora 23

* Sun Sep 13 2015 Vadim Raskhozhev <iamdexpl@gmail.com> - 0.10.2.2-1
- Update to 0.10.2.2

* Sun Jan 19 2014 Vadim Raskhozhev <iamdexpl@gmail.com> - 0.8.3.7-3.4
- Built for Fedora

* Tue Aug  6 2013 conrad@quisquis.de
- Fixed doc file list
* Tue Aug  6 2013 conrad@quisquis.de
- Use new icon
* Tue Aug  6 2013 conrad@quisquis.de
- Upgrade to 0.8.3.7
* Tue Jun 25 2013 conrad@quisquis.de
- Fixed spec + rules wrt new directory structure
* Tue Jun 25 2013 conrad@quisquis.de
- Upgrade to 0.6.9.2
* Sun Jun 23 2013 conrad@quisquis.de
- Added litecoind-safe + apparmor profile
* Mon May 13 2013 conrad@quisquis.de
- Removed cpuminer subpackage
* Mon Apr 22 2013 conrad@quisquis.de
- Fixed Fedora qmake invocation
* Mon Apr 22 2013 conrad@quisquis.de
- Added separate -gui package
- Fixed Group header
* Tue Apr 16 2013 conrad@quisquis.de
- Fixed License
- Added missing defattr
- Added desktop menu entry
* Tue Apr 16 2013 conrad@quisquis.de
- Fixed debug_install_post
* Tue Apr 16 2013 conrad@quisquis.de
- Fixed cpuminer installation
* Tue Apr 16 2013 conrad@quisquis.de
- Fixed more build deps
* Tue Apr 16 2013 conrad@quisquis.de
- Fixed build dep
* Tue Apr 16 2013 conrad@quisquis.de
- Fixed broken header
* Tue Apr 16 2013 conrad@quisquis.de
- Initial project creation
